<?php
/**
 * @copyright	Copyright (C) 2011 Simplify Your Web, Inc. All rights reserved.
 * @license		GNU General Public License version 3 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

require_once (JPATH_SITE.DS.'components'.DS.'com_content'.DS.'helpers'.DS.'route.php');
require_once (dirname(__FILE__).DS.'image.php');

jimport('joomla.application.component.model');
jimport('joomla.filesystem.file');

JModel::addIncludePath(JPATH_SITE.'/components/com_content/models', 'ContentModel');

class modLatestNewsEnhancedHelper
{
	static function getList(&$module_id, &$params)
	{
		// Get the dbo
		$db = JFactory::getDbo();
		
		// Get an instance of the generic articles model
		$model = JModel::getInstance('Articles', 'ContentModel', array('ignore_request' => true));
		
		// Set application parameters in model
		$app = JFactory::getApplication();
		$appParams = $app->getParams();
		$model->setState('params', $appParams);
		
		// Set the filters based on the module params
		$model->setState('list.start', 0);
		$model->setState('list.limit', (int) $params->get('count', 5));
		$model->setState('filter.published', 1);
		
		// Access filter
		$access = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		$model->setState('filter.access', $access);
		
		// Category filter
		$model->setState('filter.category_id', $params->get('catid', array()));
		
		// User filter
		$userId = JFactory::getUser()->get('id');
		switch ($params->get('user_id'))
		{
			case 'by_me':
				$model->setState('filter.author_id', (int) $userId);
				break;
			case 'not_me':
				$model->setState('filter.author_id', $userId);
				$model->setState('filter.author_id.include', false);
				break;		
			case '0':
				break;		
			default:
				$model->setState('filter.author_id', (int) $params->get('user_id'));
			break;
		}
		
		// Filter by language
		$model->setState('filter.language',$app->getLanguageFilter());
		
		//  Featured switch
		switch ($params->get('show_featured'))
		{
			case '1':
				$model->setState('filter.featured', 'only');
				break;
			case '0':
				$model->setState('filter.featured', 'hide');
				break;
			default:
				$model->setState('filter.featured', 'show');
			break;
		}
		
		// Set ordering
		$dir = 'DESC';
		$ordering = '';
		switch ($params->get( 'ordering' ))
		{
			case 'o_asc': $ordering = 'a.ordering'; $dir = 'ASC'; break;
			case 'o_dsc': $ordering = 'a.ordering'; break;
			case 'p_asc': $ordering = 'a.publish_up'; $dir = 'ASC'; break;
			case 'p_dsc': $ordering = 'a.publish_up'; break;
			case 'm_asc': $ordering = 'a.modified ASC, a.created'; $dir = 'ASC'; break;
			case 'm_dsc': $ordering = 'a.modified DESC, a.created'; break;
			case 'c_asc': $ordering = 'a.created'; $dir = 'ASC'; break;
			case 'c_dsc': $ordering = 'a.created'; break;
			case 'mc_asc': $ordering = 'a.created'; $dir = 'ASC'; break;
			case 'mc_dsc': $ordering = 'CASE WHEN (a.modified = '.$db->quote($db->getNullDate()).') THEN a.created ELSE a.modified END'; break;
			case 'random': $ordering = 'rand()'; $dir = ''; break;
			default: $ordering = 'a.publish_up'; break;
		}
		
		$model->setState('list.ordering', $ordering);
		$model->setState('list.direction', $dir);
		
		$items = $model->getItems();
				
		$head_type = $params->get('head_type', 'none');
		$postdate = $params->get('post_date', 'published');
		$text_type = $params->get('text', 1);
		$letter_count = $params->get('letter_count');	
		$keep_tags = $params->get('keep_tags');

		$show_author = $params->get('show_author', 1);
		$author_name = $params->get('author_name', 'full');
		$show_date = $params->get('show_date', 'none');
		
		$strip_tags = $params->get('strip_tags', 1);
		$crop_picture = $params->get('crop_picture', 0);
		$head_width = trim($params->get('head_w', '64'));
		$head_height = trim($params->get('head_h', '64'));
		$clear_cache = $params->get('clear_cache', 0);
		
		$tmp_path = $params->get('thumb_path', 'tmp/');
		
		foreach ($items as &$item) {
			$item->slug = $item->id.':'.$item->alias;
			$item->catslug = $item->catid.':'.$item->category_alias;
			
			if ($access || in_array($item->access, $authorised)) {
				// We know that user has the privilege to view the article
				$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
				$item->catlink = JRoute::_(ContentHelperRoute::getCategoryRoute($item->catslug));
			} else {
				$item->link = JRoute::_('index.php?option=com_users&view=login');
				$item->catlink = $item->link;
			}
			
			//$item->title = htmlspecialchars( $row->title );
				
			// author
			if ($show_author) {
				$user =& JFactory::getUser($item->created_by);
				switch ($author_name) {
					case 'full':
						$item->author = htmlspecialchars($user->name);
						break;
					case 'alias':
						$item->author = htmlspecialchars($item->created_by_alias);
						break;
					default:
						$item->author = htmlspecialchars($user->username);
						break;
				}
			}
			
			// image
			if ($head_type == "image") {
				$item->imagetag = '';	
					
				preg_match_all('#<img[^>]*>#i', $item->introtext, $result); // finds all images in the introtext
				if (empty($result[0][0])) {	// maybe there are images in the fulltext...					
					// missing fulltext from articles.php so get fulltext from an other query
					$db->setQuery('SELECT a.fulltext FROM #__content AS a WHERE a.id ='.$item->id);
					$fulltext = $db->loadResult();
					preg_match_all('#<img[^>]*>#i', $fulltext, $result); // finds all images in the fulltext
				}
				
				if (!empty($result[0][0])) { // $result[0][0] is the first image							
					$img = array();	
					preg_match_all('/(src)=("[^"]*")/i',$result[0][0], $img[$result[0][0]]); // get the src attribute
					foreach ($img as $ii => $value) { // loops only once						
						$extensions = get_loaded_extensions();						
						if (!in_array('gd', $extensions)) {
							// missing gd library
							//$item->imagetag = '<span>'.JText::_('MOD_LATESTNEWSENHANCED_GD_NOTLOADED').'</span>';
									
							// loops only once
							$item->imagetag = '<img ';
							foreach ($img[$ii][0] as $jj => $value) {
								$item->imagetag .= ($img[$ii][0][$jj]).' ';
							}
							$item->imagetag .= '/>';
						} else {						
							foreach ($img[$ii][0] as $jj => $value) {
								$imagesrc = trim($img[$ii][2][$jj], '"'); // works with 'allow url fopen'
								
								$imageext = explode('.', $imagesrc);
								$imageext = $imageext[count($imageext) - 1];
								$imageext = strtolower($imageext);
								
								$filename = $tmp_path.'thumb_'.$module_id.'_'.$item->id.'.'.$imageext;
								$imageheight = 0;
								if (is_file($filename) && !$clear_cache) { // thumbnail already exists								
									$imagesize = getimagesize($filename);
									$imageheight = $imagesize[1];
								} else { // create the thumbnail							
									$image = new thumbnail;
									$image->setImage($imagesrc, $imageext);
									$image->createThumb($head_width, $head_height, $crop_picture);
									$image->renderImage($filename);								
									$imageheight = $image->getHeight();
								}
								$top = ($head_height - $imageheight) / 2;
								$item->imagetag = '<img src="'.JURI::base().$filename.'" style="position:relative;top:'.$top.'px" />';
							}
						}
					}
				}
			}
			
			// date
			$item->date = $item->publish_up;
			if ($postdate == 'created') {
				$item->date = $item->created;
			} else if ($postdate == 'modified') {
				$item->date = $item->modified;
			}
			
			if ($show_date == 'ago' || $show_date == 'agohm') {
				// PHP 5.3
				//$date_time = new DateTime($item->date);
				//$today_time = new DateTime("now");
				//$interval = $today_time->diff($date_time);				
				//$item->ago = $interval->format('%a');
				
				// before PHP 5.2
				
				$date_time = strtotime(date("Y-m-d H:i:s", strtotime($item->date)));
				$today_time = strtotime(date("Y-m-d H:i:s"));
				$difference = abs($today_time - $date_time); // seconds
				
				$nbr_days = 0;
				$nbr_hours = 0;
				$nbr_mins = 0;
				$nbr_secs = 0;
				
				if ($difference < 60) { // less than 1 minute
					$nbr_secs = $difference;
				} else if ($difference < 3600) { // less than 1 hour
					$nbr_mins = $difference / 60;
					$nbr_secs = $difference % 60;
				} else if ($difference < 86400) { // less than 1 day
					$nbr_hours = $difference / 3600;
					$nbr_mins = ($difference % 3600) / 60;
					$nbr_secs = $difference % 60;
				} else { // 1 day or more
					$nbr_days = $difference / 86400;
					$nbr_hours = ($difference % 86400) / 3600;
					$nbr_mins = ($difference % 3600) / 60;
					$nbr_secs = $difference % 60;
				}
				
				$item->nbr_seconds  = intval($nbr_secs);
				$item->nbr_minutes  = intval($nbr_mins);
				$item->nbr_hours = intval($nbr_hours);
				$item->nbr_days = intval($nbr_days);	
			}
			
			$temp = '';
			
			if (trim($letter_count) == '') { // take everything
				if ($text_type) { // take introtext
					if ($strip_tags) {
						$temp = strip_tags($item->introtext);
						$temp = self::stripPluginTags($temp);
					} else {
						if (trim($keep_tags) == '') {
							$temp = $item->introtext;
							$temp = self::stripPluginTags($temp);
						} else {
							$temp = strip_tags($item->introtext, $keep_tags);
							$temp = self::stripPluginTags($temp);
						}
					}
				} else { // take metadescription
					$temp = $item->metadesc;
				}
			} else if ((int)$letter_count > 0) {
				if ($text_type) { // take introtext
					//if ($strip_tags) {
						$temp = strip_tags($item->introtext);
						$temp = self::stripPluginTags($temp);
					//} else {
						//$temp = $item->introtext;
					//}
				} else { // take metadescription
					$temp = $item->metadesc;		
				}
					
				$lenTemp = strlen($temp);				
				if ($lenTemp > $letter_count) {
					$temp = mb_substr($temp, 0, $letter_count);
					$temp .= '...';
				}
			}
			
			$item->text = $temp;
		}
		
		return $items;
	}
	
	static function stripPluginTags($output) {
			
		$plugins = array();
		
		preg_match_all('/\{\w*/', $output, $matches);
		foreach ($matches[0] as $match) {
			$match = str_replace('{', '', $match);
			if (strlen($match)) {
				$plugins[$match] = $match;
			}
		}
			
		$find = array();
		foreach ($plugins as $plugin) {
			$find[] = '\{'.$plugin.'\s?.*?\}.*?\{/'.$plugin.'\}';
			$find[] = '\{'.$plugin.'\s?.*?\}';
		}
		if(!empty($find)) {
			foreach($find as $key=>$f) {
				$f = '/'.str_replace('/','\/',$f).'/';
				$find[$key] = $f;
			}
			$output = preg_replace($find ,'', $output);
		}
		
		return $output;
	}
}
?>